# define variables used within gg expressions
# https://community.rstudio.com/t/how-to-solve-no-visible-binding-for-global-variable-note/28887
utils::globalVariables(c("anc_state_1", "anc_state_1_pp", "anc_state_2",
                         "anc_state_3","anc_state_other", "bf",
                         "clado_node_color_as", "clado_node_shape_as",
                         "clado_node_size_as", "end_state_1", "end_state_1_pp",
                         "end_state_2", "end_state_3", "end_state_other",
                         "extant", "isTip", "isTip.x", "item", "kula", "label",
                         "lower", "node_id", "observed_state", "olena",
                         "posterior", "Probability", "rate.name",
                         "start_state_1", "start_state_1_pp", "start_state_2",
                         "start_state_3", "State", "upper", "value", "Variable",
                         "vx", "vy", "x", "y", "."))
